searchNodes=[{"ref":"Fluxter.html","title":"Fluxter","type":"behaviour","doc":"InfluxDB writer for Elixir that uses InfluxDB&#39;s line protocol over UDP. To get started with Fluxter, you have to create a module that calls use Fluxter, like this: defmodule MyApp.Fluxter do use Fluxter end This way, MyApp.Fluxter becomes an InfluxDB connection pool. Each Fluxter pool provides a start_link/1 function that starts that pool and connects to InfluxDB; this function needs to be invoked before being able to send data to InfluxDB. Typically, you won&#39;t call start_link/1 directly as you&#39;ll want to add Fluxter pools to your application&#39;s supervision tree. For this use case, pools provide a child_spec/1 function: def start(_type, _args) do children = [ MyApp.Fluxter.child_spec(), # ... ] Supervisor.start_link(children, strategy: :one_for_one) end Once a Fluxter pool is started, its c:write/2,3, c:measure/2,3,4, and other functions can successfully be used to send points to the data store. A Fluxter pool implements the Fluxter behaviour, so you can read documentation for the callbacks the behaviour provides to know more about these functions. Configuration Fluxter can be configured either globally or on a per-pool basis. The global configuration will affect all Fluxter pools; it can be specified by configuring the :fluxter application: config :fluxter, host: &quot;metrics.example.com&quot;, port: 1122 The per-pool configuration can be specified by configuring the pool module under the :fluxter application: config :fluxter, MyApp.Fluxter, host: &quot;metrics.example.com&quot;, port: 1122, pool_size: 10 The following is a list of all the supported options: :host - (binary) the host to send metrics to. Defaults to &quot;127.0.0.1&quot;. :port - (integer) the port (on :host) to send the metrics to. Defaults to 8092. :prefix - (binary or nil) all metrics sent to the data store through the configured Fluxter pool will be prefixed by the value of this option. If nil, metrics will not be prefixed. Defaults to nil. :pool_size - (integer) the size of the connection pool for the given Fluxter pool. This option can only be configured on a per-pool basis; configuring it globally for the :fluxter application has no effect. Defaults to 5. Metric aggregation Fluxter supports counters: a counter is a metric aggregator designed to locally aggregate a numeric value and flush the aggregated value only once to the storage, as a single metric. This is very useful when you have the need to write a high number of metrics in a very short amount of time. Doing so can have a negative impact on the speed of your code and can also cause network packet drops. For example, code like the following: for value &lt;- 1..1_000_000 do my_operation(value) MyApp.Fluxter.write(&quot;my_operation_success&quot;, [host: &quot;eu-west&quot;], 1) end can take advantage of metric aggregation: counter = MyApp.Fluxter.start_counter(&quot;my_operation_success&quot;, [host: &quot;eu-west&quot;]) for value &lt;- 1..1_000_000 do my_operation(value) MyApp.Fluxter.increment_counter(counter, 1) end MyApp.Fluxter.flush_counter(counter)"},{"ref":"Fluxter.html#c:child_spec/0","title":"Fluxter.child_spec/0","type":"callback","doc":"Should be the same as child_spec([])."},{"ref":"Fluxter.html#c:child_spec/1","title":"Fluxter.child_spec/1","type":"callback","doc":"Returns a child specification for this Fluxter pool. This is usually used to supervise this Fluxter pool under the supervision tree of your application: def start(_type, _args) do children = [ MyApp.Fluxter.child_spec([]), # ... ] Supervisor.start_link(children, strategy: :one_for_one) end options is a list of options that will be given to start_link/1."},{"ref":"Fluxter.html#c:flush_counter/1","title":"Fluxter.flush_counter/1","type":"callback","doc":"Flushes the given counter by writing its aggregated value as a single metric. This function performs a fire-and-forget operation (a cast) on the given counter, hence it will always return :ok. This function will also stop the counter process after the metric is flushed. See the &quot;Metric aggregation&quot; section in the documentation for Fluxter for more information on counters. Examples Assuming a MyApp.Fluxter Fluxter pool exists: iex&gt; MyApp.Fluxter.flush_counter(counter) :ok"},{"ref":"Fluxter.html#c:increment_counter/2","title":"Fluxter.increment_counter/2","type":"callback","doc":"Adds the extra value to the given counter. This function adds the extra value (a number) to the current value of the given counter. To subtract, just use a negative number to add to the current value of counter. This function performs a fire-and-forget operation (a cast) on the given counter, hence it will always return :ok. See the &quot;Metric aggregation&quot; section in the documentation for Fluxter for more information on counters. Examples Assuming a MyApp.Fluxter Fluxter pool exists: iex&gt; MyApp.Fluxter.increment_counter(counter, 1) :ok"},{"ref":"Fluxter.html#c:measure/2","title":"Fluxter.measure/2","type":"callback","doc":"Should be the same as measure(measurement, [], [], fun_or_mfa)."},{"ref":"Fluxter.html#c:measure/3","title":"Fluxter.measure/3","type":"callback","doc":"Should be the same as measure(measurement, tags, [], fun_or_mfa)."},{"ref":"Fluxter.html#c:measure/4","title":"Fluxter.measure/4","type":"callback","doc":"Measures the execution time of fun_or_mfa and writes it as a metric. This function is just an utility function to measure the execution time of a given function fun_or_mfa. The measurement and tags arguments work in the same way as in write/3. fun_or_mfa&#39;s execution time is prepended as a field called value to the already existing list of fields. This means that if there&#39;s already a field called value in fields, it will be overridden by the measurement. This also means that fields must be a list of key-value pairs (field name and value): simple floats, integers, booleans, and binaries as values for fields are not supported like they are in write/3. This function returns whatever fun returns. Examples Assuming a MyApp.Fluxter Fluxter pool exists: iex&gt; MyApp.Fluxter.measure &quot;task_exec_time&quot;, [host: &quot;us-east&quot;], fn -&gt; ...&gt; 1 + 1 ...&gt; end 2"},{"ref":"Fluxter.html#c:start_counter/1","title":"Fluxter.start_counter/1","type":"callback","doc":"Should be the same as start_counter(measurement, [], [])."},{"ref":"Fluxter.html#c:start_counter/2","title":"Fluxter.start_counter/2","type":"callback","doc":"Should be the same as start_counter(measurement, tags, [])."},{"ref":"Fluxter.html#c:start_counter/3","title":"Fluxter.start_counter/3","type":"callback","doc":"Starts a counter for a metric. The purpose of this counter is to aggregate a numeric metric: values aggregated in the counter will only be written to the storage as a single metric when the counter is &quot;flushed&quot; (see flush_counter/1). tags and fields will be tags and fields attached to the metric when it&#39;s flushed. The aggregated value of the metric will be prepended to fields as a field called value; this means that if there&#39;s already a field called value in fields, it will be overridden. This function spawns a process that is linked to the caller process. The linking part is important because it means that if the parent process dies, the counter will be terminated as well and its aggregated metric will be lost. See the &quot;Metric aggregation&quot; section in the documentation for Fluxter for more information on counters. Examples Assuming a MyApp.Fluxter Fluxter pool exists: iex&gt; MyApp.Fluxter.start_counter(&quot;hits&quot;, [host: &quot;us-west&quot;]) {:ok, #PID&lt;...&gt;}"},{"ref":"Fluxter.html#c:start_link/0","title":"Fluxter.start_link/0","type":"callback","doc":"Should be the same as start_link([])."},{"ref":"Fluxter.html#c:start_link/1","title":"Fluxter.start_link/1","type":"callback","doc":"Starts this Fluxter pool. A Fluxter pool is a set of processes supervised by a supervisor; this function starts all those processes and that supervisor. The following options are supported: :host, :port, and :prefix. If you plan on having a Fluxter pool started under your application&#39;s supervision tree, use child_spec/1."},{"ref":"Fluxter.html#c:write/2","title":"Fluxter.write/2","type":"callback","doc":"Should be the same as write(measurement, [], fields)."},{"ref":"Fluxter.html#c:write/3","title":"Fluxter.write/3","type":"callback","doc":"Writes a metric to the data store. measurement is the name of the metric to write. tags is a list of key-value pairs that specifies tags (as name and value) for the data point to write; note that tag values are converted to strings as InfluxDB only support string values for tags. fields can either be a list of key-value pairs, in which case it specifies a list of fields (as name and value), or a single value (specifically, a boolean, float, integer, or binary). In the latter case, the default field name of value will be used: calling write(&quot;foo&quot;, [], 4.3) is the same as calling write(&quot;foo&quot;, [], value: 4.3). The return value is always :ok as writing is a fire-and-forget operation. Examples Assuming a MyApp.Fluxter Fluxter pool exists: iex&gt; MyApp.Fluxter.write(&quot;cpu_temp&quot;, [host: &quot;eu-west&quot;], 68) :ok"},{"ref":"Fluxter.html#t:counter/0","title":"Fluxter.counter/0","type":"opaque","doc":""},{"ref":"Fluxter.html#t:field_value/0","title":"Fluxter.field_value/0","type":"type","doc":""},{"ref":"Fluxter.html#t:fields/0","title":"Fluxter.fields/0","type":"type","doc":""},{"ref":"Fluxter.html#t:measurement/0","title":"Fluxter.measurement/0","type":"type","doc":""},{"ref":"Fluxter.html#t:tags/0","title":"Fluxter.tags/0","type":"type","doc":""},{"ref":"readme.html","title":"Fluxter","type":"extras","doc":"Fluxter Fluxter is an InfluxDB writer for Elixir. It uses InfluxDB&#39;s line protocol over UDP."},{"ref":"readme.html#installation","title":"Fluxter - Installation","type":"extras","doc":"Add Fluxter as a dependency to your mix.exs file: defp deps() do [{:fluxter, &quot;~&gt; 0.8&quot;}] end Then run mix deps.get in your shell to fetch the dependencies."},{"ref":"readme.html#usage","title":"Fluxter - Usage","type":"extras","doc":"See the documentation for detailed usage information. A module that uses Fluxter becomes an InfluxDB connection pool: defmodule MyApp.Fluxter do use Fluxter end Each Fluxter pool provides a start_link/1 function that starts the pool and connects to InfluxDB; this function needs to be invoked before the pool can be used. Typically, you won&#39;t call start_link/1 directly as you&#39;ll want to add a Fluxter pool to your application&#39;s supervision tree. For this use case, pools provide a child_spec/1 function: def start(_type, _args) do children = [ MyApp.Fluxter.child_spec(), #... ] Supervisor.start_link(children, strategy: :one_for_one) end Once the Fluxter pool is started, its write/2,3, measure/2,3,4, and other functions can successfully be used to send points to the data store."},{"ref":"readme.html#license","title":"Fluxter - License","type":"extras","doc":"This software is licensed under the ISC license."},{"ref":"changelog.html","title":"Changelog","type":"extras","doc":"Changelog"},{"ref":"changelog.html#v0-9-1","title":"Changelog - v0.9.1","type":"extras","doc":"Fixed the order when building prefix."},{"ref":"changelog.html#v0-9-0","title":"Changelog - v0.9.0","type":"extras","doc":"Fixed prefix building when start options provided. Dropped support for Elixir v1.2."},{"ref":"changelog.html#v0-8-1","title":"Changelog - v0.8.1","type":"extras","doc":"Fixed port command for OTP versions that support ancillary data sending."},{"ref":"changelog.html#v0-8-0","title":"Changelog - v0.8.0","type":"extras","doc":"Added support for module, function, arguments tuple in measure/4."},{"ref":"changelog.html#v0-7-1","title":"Changelog - v0.7.1","type":"extras","doc":"Fixed Elixir v1.6 warnings."},{"ref":"changelog.html#v0-7-0","title":"Changelog - v0.7.0","type":"extras","doc":"Added the Fluxter.start_link/1 callback to support runtime configuration. Deprecations: Passing child specification options to child_spec/1 is deprecated."},{"ref":"changelog.html#v0-6-1","title":"Changelog - v0.6.1","type":"extras","doc":"Fixed a bug in the Fluxter.child_spec/1 callback."},{"ref":"changelog.html#v0-6-0","title":"Changelog - v0.6.0","type":"extras","doc":"Added the Fluxter.child_spec/1 callback. Started flushing counters synchronously when calling Fluxter.flush_counter/1."}]